package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import java.math.BigInteger;
import java.util.Enumeration;

public class DSAParameter extends ASN1Encodable {
   DERInteger p;
   DERInteger q;
   DERInteger g;

   public static DSAParameter getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static DSAParameter getInstance(Object obj) {
      if (obj != null && !(obj instanceof DSAParameter)) {
         if (obj instanceof ASN1Sequence) {
            return new DSAParameter((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid DSAParameter: " + obj.getClass().getName());
         }
      } else {
         return (DSAParameter)obj;
      }
   }

   public DSAParameter(BigInteger p, BigInteger q, BigInteger g) {
      DSAParameter var10000 = this;
      DSAParameter var10001 = this;
      DSAParameter var10002 = this;
      super();
      DERInteger var4;
      var4 = new DERInteger.<init>(p);
      var10002.p = var4;
      var4 = new DERInteger.<init>(q);
      var10001.q = var4;
      var4 = new DERInteger.<init>(g);
      var10000.g = var4;
   }

   public DSAParameter(ASN1Sequence seq) {
      if (seq.size() == 3) {
         DSAParameter var10000 = this;
         DSAParameter var10001 = this;
         Enumeration var2;
         this.p = DERInteger.getInstance((var2 = seq.getObjects()).nextElement());
         var10001.q = DERInteger.getInstance(var2.nextElement());
         var10000.g = DERInteger.getInstance(var2.nextElement());
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public BigInteger getP() {
      return this.p.getPositiveValue();
   }

   public BigInteger getQ() {
      return this.q.getPositiveValue();
   }

   public BigInteger getG() {
      return this.g.getPositiveValue();
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.p);
      var1.add(this.q);
      var10000.add(this.g);
      return new DERSequence(var1);
   }
}
